# pyprelude

[![View on PyPI](https://img.shields.io/pypi/v/pyprelude.svg)](https://pypi.python.org/pypi/pyprelude)
[![Licence](https://img.shields.io/badge/license-MIT-blue.svg)](https://raw.githubusercontent.com/rcook/pyprelude/master/LICENSE)

General-purpose Python support functions

## Install prerequisites

```
pip install setuptools-markdown
```

## Licence

[MIT License][licence]

Copyright &copy; 2017 Richard Cook

[licence]: LICENSE
[pypi]: https://pypi.python.org/pypi